@@ -2,20 +2,26 @@
 
 # used for building with djgpp cross toolchain
 
-PREFIX=/usr/local/cross-djgpp
 TARGET=i586-pc-msdosdjgpp
+PREFIX=/usr/local/cross-djgpp
 
-PATH="$PREFIX/bin:$PREFIX/$TARGET/bin:$PATH"
+PATH="$PREFIX/bin:$PATH"
 export PATH
 
 DOSBUILD=1
+export DOSBUILD
 
 CC="$TARGET-gcc"
 AS="$TARGET-as"
+RANLIB="$TARGET-ranlib"
 AR="$TARGET-ar"
-NASM="nasm"
+export CC AS RANLIB AR
 
-export CC NASM AS AR DOSBUILD
+STRIPPER="$TARGET-strip"
+if [ "$1" = "strip" ]; then
+	$STRIPPER vispatch.exe
+	exit 0
+fi
 
 HOST_OS=`uname|sed -e s/_.*//|tr '[:upper:]' '[:lower:]'`
 
