@@ -2,9 +2,9 @@
  * VisPatch :  Quake level patcher for water visibility.
  *
  * Copyright (C) 1997-2006  Andy Bay <IMarvinTPA@bigfoot.com>
- * Copyright (C) 2006-2008  O. Sezer <sezero@users.sourceforge.net>
+ * Copyright (C) 2006-2011  O. Sezer <sezero@users.sourceforge.net>
  *
- * $Id: vispatch.c,v 1.8 2008/03/17 21:45:16 sezero Exp $
+ * $Id: vispatch.c,v 1.13 2011/10/08 12:33:03 sezero Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -136,13 +136,12 @@ static void usage (void)
 	printf("  Retrieve all vis data from the files in the directory\n");
 	printf("  hipnotic, and dump it into a file named vispatch.dat\n");
 #endif
-	exit (0);
 }
 
 
 /*============================================================================*/
 
-#if defined(PLATFORM_WINDOWS)
+#if (defined(__MINGW32__) || defined(__MINGW64__))
 
 /* From MinGW runtime/init.c :
  * [...] GetMainArgs (used below) takes a fourth argument
@@ -158,16 +157,19 @@ static void usage (void)
  */
 int	_CRT_glob = 0;
 
-#endif	/* PLATFORM_WINDOWS */
+#endif	/* __MINGW32__ / __MINGW64__ */
 
 
+static const char authors[] = "Andy Bay, O. Sezer";
+
 int main (int argc, char **argv)
 {
 	int	ret = 0, tmp;
 	char	*testname;
 
-	printf("VisPatch %d.%d.%d by Andy Bay\n", VP_VER_MAJ, VP_VER_MID, VP_VER_MIN);
-	printf("Revised and fixed by O.Sezer\n");
+	printf("VisPatch %d.%d.%d by %s\n",
+			 VP_VER_MAJ, VP_VER_MID, VP_VER_MIN,
+			 authors);
 
 	ValidateByteorder ();
 
@@ -175,12 +177,18 @@ int main (int argc, char **argv)
 	{
 		for (tmp = 1; tmp < argc; tmp++)
 		{
+			if (argv[tmp][0] == '/')
+				argv[tmp][0] = '-';
+
 			q_strlwr(argv[tmp]);
 			if (strcmp(argv[tmp], "-?"    ) == 0 ||
 			    strcmp(argv[tmp], "-h"    ) == 0 ||
 			    strcmp(argv[tmp], "-help" ) == 0 ||
 			    strcmp(argv[tmp], "--help") == 0 )
+			{
 				usage();
+				exit (0);
+			}
 		}
 	}
 
@@ -192,11 +200,8 @@ int main (int argc, char **argv)
 	{
 		for (tmp = 1; tmp < argc; tmp++)
 		{
-			if (argv[tmp][0] == '-' || argv[tmp][0] == '/')
+			if (argv[tmp][0] == '-')
 			{
-				if (argv[tmp][0] == '/')
-					argv[tmp][0] = '-';
-
 				if (strcmp(argv[tmp],"-data") == 0)
 				{
 					argv[tmp][0] = 0;
@@ -591,7 +596,7 @@ static int BSPFix (int InitOFFS)
 				char *cc;
 				tmp = LittleLong(NewPakEnt[NPcnt].size);
 				if (tmp < 0)
-					Error ("%s: Error: negative size!", __thisfunc__);
+					Error ("BSPFix: negative size!");
 				cc = (char *)malloc(tmp);
 				fread(cc, 1, tmp, InFile);
 				test = fwrite(cc, 1, tmp, OutFile);
